@@ -46,6 +46,10 @@ DB_DIR = RUNTIME_ROOT / "db"
 DEFAULT_DB_URL = f"sqlite:///{DB_DIR}/spellbot.db"
 TMP_DIR = RUNTIME_ROOT / "tmp"
 MIGRATIONS_DIR = SCRIPTS_DIR / "migrations"
+INVITE_LINK = (
+    "https://discordapp.com/api/oauth2/authorize"
+    "?client_id=725510263251402832&permissions=92224&scope=bot"
+)
 
 logger = logging.getLogger(__name__)
 
@@ -839,6 +843,8 @@ class SpellBot(discord.Client):
             " <https://github.com/lexicalunit/spellbot/issues>!"
         )
         usage += "\n"
+        usage += f"[🔗 Add SpellBot to your Discord!]({INVITE_LINK})\n"
+        usage += "\n"
         usage += (
             "\n💜 You can help keep SpellBot running by supporting me on Ko-fi! "
             "<https://ko-fi.com/Y8Y51VTHZ>"
@@ -872,10 +878,12 @@ class SpellBot(discord.Client):
             "Having issues with SpellBot? "
             "Please [report bugs](https://github.com/lexicalunit/spellbot/issues)!\n"
             "\n"
+            f"[🔗 Add SpellBot to your Discord!]({INVITE_LINK})\n"
+            "\n"
             "💜 Help keep SpellBot running by "
             "[supporting me on Ko-fi!](https://ko-fi.com/Y8Y51VTHZ)"
         )
-        embed.url = "https://github.com/lexicalunit/spellbot"
+        embed.url = "http://spellbot.io/"
         embed.set_footer(text="MIT © amy@lexicalunit et al")
         embed.color = discord.Color(0x5A3EFD)
         await message.channel.send(embed=embed)
@@ -921,10 +929,22 @@ class SpellBot(discord.Client):
             )
             return
 
+        game: Optional[Game] = None
+        found_existing = False
+        join_existing = False
+
         mentioned_users = []
         for mentioned in mentions:
             mentioned_user = self.ensure_user_exists(session, mentioned)
-            if mentioned_user.waiting:
+            if (
+                len(mentions) == 1
+                and mentioned_user.game
+                and mentioned_user.game.status == "pending"
+            ):
+                game = mentioned_user.game
+                found_existing = True
+                join_existing = True
+            elif mentioned_user.waiting:
                 await message.channel.send(
                     s(
                         "lfg_mention_already",
@@ -946,11 +966,12 @@ class SpellBot(discord.Client):
         expires_at = now + timedelta(minutes=server.expire)
         user.invited = False
 
-        found_existing = False
-        seats = 1 + len(mentions)
-        game = Game.find_existing(
-            session, server, message.channel.id, size, seats, tags, system
-        )
+        if not game:
+            seats = 1 + len(mentions)
+            game = Game.find_existing(
+                session, server, message.channel.id, size, seats, tags, system
+            )
+
         if game:
             found_existing = True
             user.game = game
@@ -966,7 +987,7 @@ class SpellBot(discord.Client):
                 )
                 return
 
-            user.game = Game(
+            game = Game(
                 created_at=now,
                 updated_at=now,
                 expires_at=expires_at,
@@ -976,56 +997,57 @@ class SpellBot(discord.Client):
                 tags=tags,
                 server=server,
             )
-        for mentioned_user in mentioned_users:
-            mentioned_user.game = user.game
-            mentioned_user.invited = True
-            mentioned_user.invite_confirmed = False
+            user.game = game
+        if not join_existing:
+            for mentioned_user in mentioned_users:
+                mentioned_user.game = game
+                mentioned_user.invited = True
+                mentioned_user.invite_confirmed = False
         session.commit()
 
         mentionor = message.author
         mentionor_xid = cast(Any, mentionor).id  # typing doesn't recognize author.id
 
-        if mentioned_users:
-            for mentioned in mentions:
-                await mentioned.send(
-                    s(
-                        "lfg_invited",
-                        reply=f"<@{mentioned.id}>",
-                        mention=f"<@{mentionor_xid}>",
+        if not join_existing:
+            if mentioned_users:
+                for mentioned in mentions:
+                    await mentioned.send(
+                        s(
+                            "lfg_invited",
+                            reply=f"<@{mentioned.id}>",
+                            mention=f"<@{mentionor_xid}>",
+                        )
                     )
-                )
-            return  # we can't create the game post until we get confirmations
+                return  # we can't create the game post until we get confirmations
 
-        if found_existing and user.game.message_xid:
-            post = await self.safe_fetch_message(message.channel, user.game.message_xid)
+        if found_existing and game.message_xid:
+            post = await self.safe_fetch_message(message.channel, game.message_xid)
             if post:
                 await message.channel.send(s("play_found", reply=f"<@{mentionor_xid}>"))
                 found_discord_users = []
-                if len(cast(List[User], user.game.users)) == user.game.size:
-                    for game_user in user.game.users:
+                if len(cast(List[User], game.users)) == game.size:
+                    for game_user in game.users:
                         discord_user = await self.safe_fetch_user(game_user.xid)
                         if not discord_user:  # user has left the server since signing up
                             game_user.game_id = None
                         else:
                             found_discord_users.append(discord_user)
 
-                if len(found_discord_users) == user.game.size:  # game is ready
-                    user.game.url = (
-                        self.create_game() if user.game.system == "spelltable" else None
-                    )
-                    user.game.status = "started"
+                if len(found_discord_users) == game.size:  # game is ready
+                    game.url = self.create_game() if game.system == "spelltable" else None
+                    game.status = "started"
                     session.commit()
                     for discord_user in found_discord_users:
-                        await discord_user.send(embed=user.game.to_embed())
-                    await self.safe_edit_message(post, embed=user.game.to_embed())
+                        await discord_user.send(embed=game.to_embed())
+                    await self.safe_edit_message(post, embed=game.to_embed())
                     await self.safe_clear_reactions(post)
                 else:
                     session.commit()
-                    await self.safe_edit_message(post, embed=user.game.to_embed())
+                    await self.safe_edit_message(post, embed=game.to_embed())
                 return  # Done!
 
-        post = await message.channel.send(embed=user.game.to_embed())
-        user.game.message_xid = post.id
+        post = await message.channel.send(embed=game.to_embed())
+        game.message_xid = post.id
         session.commit()
         await post.add_reaction("➕")
         await post.add_reaction("➖")
@@ -1530,13 +1552,9 @@ class SpellBot(discord.Client):
         * `channel <list>`: Set SpellBot to only respond in the given list of channels.
         * `prefix <string>`: Set SpellBot's command prefix for text channels.
         * `expire <number>`: Set the number of minutes before pending games expire.
+        * `help`: Get detailed usage help for SpellBot.
         & <subcommand> [subcommand parameters]
         """
-        if not is_admin(message.channel, message.author):
-            await message.channel.send(
-                s("not_admin", reply=f"<@{cast(discord.User, message.author).id}>")
-            )
-            return
         if not params:
             await message.channel.send(
                 s(
@@ -1546,9 +1564,18 @@ class SpellBot(discord.Client):
             )
             return
 
-        server = self.ensure_server_exists(session, message.channel.guild.id)
-
         command = params[0]
+        if command == "help":
+            await self.spellbot_help(session, prefix, params[1:], message)
+            return
+
+        if not is_admin(message.channel, message.author):
+            await message.channel.send(
+                s("not_admin", reply=f"<@{cast(discord.User, message.author).id}>")
+            )
+            return
+
+        server = self.ensure_server_exists(session, message.channel.guild.id)
         if command == "channels":
             await self.spellbot_channels(session, server, params[1:], message)
         elif command == "prefix":
@@ -1700,6 +1727,11 @@ class SpellBot(discord.Client):
         embed.set_footer(text=f"Config for Guild ID: {server.guild_xid}")
         await message.channel.send(embed=embed)
 
+    async def spellbot_help(
+        self, session: Session, prefix: str, params: List[str], message: discord.Message,
+    ) -> None:
+        await self.help(session, prefix, params, message)
+
 
 def get_db_env(fallback: str) -> str:  # pragma: no cover
     """Returns the database env var from the environment or else the given gallback."""
